resultSet.BitmapResultSet

|  | ## Cheshire3 Object Model: Class BitmapResultSet

Module resultSet :: Class BitmapResultSet

## Class BitmapResultSet
source code

Object Tree:

    baseObjects.ResultSet --+
                            |
                           BitmapResultSet

Instance Methods

__init__(self, session, data=0, recordStore=None)
__getitem__(self, k)
__len__(self)
serialise(self)
deserialise(self, data)
get_item(self, item)
combine(self, session, others, clause, db=None)
order(self, spec)
retrieve(self, numReq, start, cache=0)
Inherited from `baseObjects.ResultSet`: `sort`

Class Variables

bitfield |
currItems |
recordStore |
termid |
totalOccs |
totalRecs |
id |
index |
queryTerm |
queryFreq |
queryFragment |
queryPositions |
relevancy |
maxWeight |
minWeight |
Inherited from `baseObjects.ResultSet`: `expires`

Method Details

### __init__(self, session, data=0, recordStore=None) (Constructor) | source code

### __getitem__(self, k) (Indexing operator) | source code

### __len__(self) (Length operator) | source code

### serialise(self) | source code

### deserialise(self, data) | source code

### get_item(self, item) | source code

### combine(self, session, others, clause, db=None) | source code
Overrides: baseObjects.ResultSet.combine

### order(self, spec) | source code

### retrieve(self, numReq, start, cache=0) | source code
Overrides: baseObjects.ResultSet.retrieve

Class Variable Details

    ### bitfield Value:
        None

    ### currItems Value:
        None

    ### recordStore Value:
        None

    ### termid Value:
        -1

    ### totalOccs Value:
        0

    ### totalRecs Value:
        0

    ### id Value:
        ""

    ### index Value:
        None

    ### queryTerm Value:
        ""

    ### queryFreq Value:
        0

    ### queryFragment Value:
        None

    ### queryPositions Value:
        []

    ### relevancy Value:
        0

    ### maxWeight Value:
        0

    ### minWeight Value:
        0